==> graph-api-0.21.4-sources.jar: org/opendaylight/yang/svc/v1/urn/opendaylight/params/xml/ns/yang/graph/rev220720/YangModuleInfoImpl.java <==
package org.opendaylight.yang.svc.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720;

import com.google.common.collect.ImmutableSet;
import java.lang.Override;
import java.lang.String;
import java.util.HashSet;
import java.util.Set;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yangtools.yang.binding.ResourceYangModuleInfo;
import org.opendaylight.yangtools.yang.binding.YangModuleInfo;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * The {@link ResourceYangModuleInfo} for {@code graph} module.
 */
@javax.annotation.processing.Generated("mdsal-binding-generator")
public final class YangModuleInfoImpl extends ResourceYangModuleInfo {
    private static final @NonNull QName NAME = QName.create("urn:opendaylight:params:xml:ns:yang:graph", "2022-07-20", "graph").intern();
    private static final @NonNull YangModuleInfo INSTANCE = new YangModuleInfoImpl();

    private final @NonNull ImmutableSet<YangModuleInfo> importedModules;

    /**
     * Return the singleton instance of this class.
     *
     * @return The singleton instance
     */
    public static @NonNull YangModuleInfo getInstance() {
        return INSTANCE;
    }

    /**
     * Create an interned {@link QName} with specified {@code localName} and namespace/revision of this
     * module.
     *
     * @param localName local name
     * @return A QName
     * @throws NullPointerException if {@code localName} is {@code null}
     * @throws IllegalArgumentException if {@code localName} is not a valid YANG identifier
     */
    public static @NonNull QName qnameOf(final String localName) {
        return QName.create(NAME, localName).intern();
    }

    private YangModuleInfoImpl() {
        Set<YangModuleInfo> set = new HashSet<>();
        set.add(org.opendaylight.yang.svc.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.svc.v1.urn.ietf.params.xml.ns.yang.ietf.routing.types.rev171204.YangModuleInfoImpl.getInstance());
        importedModules = ImmutableSet.copyOf(set);
    }
    
    @Override
    public QName getName() {
        return NAME;
    }
    
    @Override
    protected String resourceName() {
        return "/META-INF/yang/graph@2022-07-20.yang";
    }
    
    @Override
    public ImmutableSet<YangModuleInfo> getImportedModules() {
        return importedModules;
    }
}

==> graph-api-0.22.7-sources.jar: org/opendaylight/yang/svc/v1/urn/opendaylight/params/xml/ns/yang/graph/rev220720/YangModuleInfoImpl.java <==
package org.opendaylight.yang.svc.v1.urn.opendaylight.params.xml.ns.yang.graph.rev220720;

import com.google.common.collect.ImmutableSet;
import java.lang.Override;
import java.lang.String;
import java.util.HashSet;
import java.util.Set;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yangtools.binding.lib.ResourceYangModuleInfo;
import org.opendaylight.yangtools.binding.meta.YangModuleInfo;
import org.opendaylight.yangtools.yang.common.QName;

/**
 * The {@link ResourceYangModuleInfo} for {@code graph} module.
 */
@javax.annotation.processing.Generated("mdsal-binding-generator")
public final class YangModuleInfoImpl extends ResourceYangModuleInfo {
    private static final @NonNull QName NAME = QName.create("urn:opendaylight:params:xml:ns:yang:graph", "2022-07-20", "graph").intern();
    private static final @NonNull YangModuleInfo INSTANCE = new YangModuleInfoImpl();

    private final @NonNull ImmutableSet<YangModuleInfo> importedModules;

    /**
     * Return the singleton instance of this class.
     *
     * @return The singleton instance
     */
    public static @NonNull YangModuleInfo getInstance() {
        return INSTANCE;
    }

    /**
     * Create an interned {@link QName} with specified {@code localName} and namespace/revision of this
     * module.
     *
     * @param localName local name
     * @return A QName
     * @throws NullPointerException if {@code localName} is {@code null}
     * @throws IllegalArgumentException if {@code localName} is not a valid YANG identifier
     */
    public static @NonNull QName qnameOf(final String localName) {
        return QName.create(NAME, localName).intern();
    }

    private YangModuleInfoImpl() {
        Set<YangModuleInfo> set = new HashSet<>();
        set.add(org.opendaylight.yang.svc.v1.urn.ietf.params.xml.ns.yang.ietf.inet.types.rev130715.YangModuleInfoImpl.getInstance());
        set.add(org.opendaylight.yang.svc.v1.urn.ietf.params.xml.ns.yang.ietf.routing.types.rev171204.YangModuleInfoImpl.getInstance());
        importedModules = ImmutableSet.copyOf(set);
    }
    
    @Override
    public QName getName() {
        return NAME;
    }
    
    @Override
    protected String resourceName() {
        return "/META-INF/yang/graph@2022-07-20.yang";
    }
    
    @Override
    public ImmutableSet<YangModuleInfo> getImportedModules() {
        return importedModules;
    }
}
